@@ -5,33 +5,32 @@ Enhanced document management with Material Icons and optimized queries.
 """
 
 from django.contrib import admin, messages
-from django.db import models, IntegrityError
+from django.db import IntegrityError, models
 from django.db.models.fields.json import JSONField
 from django_json_widget.widgets import JSONEditorWidget
 from unfold.admin import ModelAdmin, TabularInline
 from unfold.contrib.filters.admin import AutocompleteSelectFilter, AutocompleteSelectMultipleFilter
 from unfold.contrib.forms.widgets import WysiwygWidget
-from django_cfg import ImportExportModelAdmin, ImportForm, ExportForm
 
+from django_cfg import ExportForm, ImportExportModelAdmin, ImportForm
 from django_cfg.modules.django_admin import (
-    OptimizedModelAdmin,
-    DisplayMixin,
-    Icons,
     ActionVariant,
+    DisplayMixin,
+    OptimizedModelAdmin,
+    action,
     display,
-    action
 )
 from django_cfg.modules.django_admin.utils.badges import StatusBadge
 
-from ..models import Document, DocumentChunk, DocumentCategory
+from ..models import Document, DocumentCategory, DocumentChunk
+from .actions import VisibilityActions
 from .helpers import (
+    CategoryStatistics,
+    ChunkStatistics,
+    DocumentAdminConfigs,
     DocumentDisplayHelpers,
     DocumentStatistics,
-    ChunkStatistics,
-    CategoryStatistics,
-    DocumentAdminConfigs
 )
-from .actions import VisibilityActions
 
 
 class DocumentChunkInline(TabularInline):
