@@ -4,9 +4,11 @@ Subscription managers for the Universal Payment System v2.0.
 Optimized querysets and managers for subscription and endpoint group operations.
 """
 
+from datetime import timedelta
+
 from django.db import models
 from django.utils import timezone
-from datetime import timedelta
+
 from django_cfg.modules.django_logging import get_logger
 
 logger = get_logger("subscription_managers")
@@ -18,23 +20,23 @@ class SubscriptionQuerySet(models.QuerySet):
     
     Provides efficient queries for subscription management and access control.
     """
-    
+
     def optimized(self):
         """Prevent N+1 queries with select_related and prefetch_related."""
         return self.select_related('user').prefetch_related('endpoint_groups')
-    
+
     def by_user(self, user):
         """Filter subscriptions by user."""
         return self.filter(user=user)
-    
+
     def by_tier(self, tier):
         """Filter by subscription tier."""
         return self.filter(tier=tier)
-    
+
     def by_status(self, status):
         """Filter by subscription status."""
         return self.filter(status=status)
-    
+
     # Status-based filters
     def active(self):
         """
@@ -46,19 +48,19 @@ class SubscriptionQuerySet(models.QuerySet):
             status='active',
             expires_at__gt=timezone.now()
         )
-    
+
     def inactive(self):
         """Get inactive subscriptions."""
         return self.filter(status='inactive')
-    
+
     def suspended(self):
         """Get suspended subscriptions."""
         return self.filter(status='suspended')
-    
+
     def cancelled(self):
         """Get cancelled subscriptions."""
         return self.filter(status='cancelled')
-    
+
     def expired(self):
         """
         Get expired subscriptions.
@@ -66,7 +68,7 @@ class SubscriptionQuerySet(models.QuerySet):
         Returns subscriptions where expires_at <= now, regardless of status.
         """
         return self.filter(expires_at__lte=timezone.now())
-    
+
     def expiring_soon(self, days=7):
         """
         Get subscriptions expiring in the next N days.
@@ -80,28 +82,28 @@ class SubscriptionQuerySet(models.QuerySet):
             expires_at__gt=timezone.now(),
             status='active'
         )
-    
+
     # Tier-based filters
     def free_tier(self):
         """Get free tier subscriptions."""
         return self.filter(tier='free')
-    
+
     def basic_tier(self):
         """Get basic tier subscriptions."""
         return self.filter(tier='basic')
-    
+
     def pro_tier(self):
         """Get pro tier subscriptions."""
         return self.filter(tier='pro')
-    
+
     def enterprise_tier(self):
         """Get enterprise tier subscriptions."""
         return self.filter(tier='enterprise')
-    
+
     def paid_tiers(self):
         """Get paid tier subscriptions (non-free)."""
         return self.exclude(tier='free')
-    
+
     # Time-based filters
     def created_recently(self, days=30):
         """
@@ -112,7 +114,7 @@ class SubscriptionQuerySet(models.QuerySet):
         """
         since = timezone.now() - timedelta(days=days)
         return self.filter(created_at__gte=since)
-    
+
     def renewed_recently(self, days=30):
         """
         Get subscriptions renewed in the last N days.
@@ -122,16 +124,16 @@ class SubscriptionQuerySet(models.QuerySet):
         """
         since = timezone.now() - timedelta(days=days)
         return self.filter(updated_at__gte=since, status='active')
-    
+
     # Usage-based filters
     def with_usage(self):
         """Get subscriptions that have been used (total_requests > 0)."""
         return self.filter(total_requests__gt=0)
-    
+
     def without_usage(self):
         """Get subscriptions that have never been used."""
         return self.filter(total_requests=0)
-    
+
     def high_usage(self, threshold=1000):
         """
         Get subscriptions with high usage.
@@ -140,7 +142,7 @@ class SubscriptionQuerySet(models.QuerySet):
             threshold: Request count threshold (default: 1000)
         """
         return self.filter(total_requests__gte=threshold)
-    
+
     def recent_usage(self, hours=24):
         """
         Get subscriptions used in the last N hours.
@@ -150,16 +152,16 @@ class SubscriptionQuerySet(models.QuerySet):
         """
         since = timezone.now() - timedelta(hours=hours)
         return self.filter(last_request_at__gte=since)
-    
+
     # Auto-renewal filters
     def auto_renewing(self):
         """Get subscriptions with auto-renewal enabled."""
         return self.filter(auto_renew=True)
-    
+
     def manual_renewal(self):
         """Get subscriptions with manual renewal."""
         return self.filter(auto_renew=False)
-    
+
     # Endpoint access filters
     def with_endpoint_access(self, endpoint_group_code):
         """
@@ -172,26 +174,26 @@ class SubscriptionQuerySet(models.QuerySet):
             endpoint_groups__code=endpoint_group_code,
             endpoint_groups__is_enabled=True
         )
-    
+
     # Aggregation methods
     def total_revenue(self):
         """Get total monthly revenue from active subscriptions."""
         result = self.active().aggregate(total=models.Sum('monthly_cost_usd'))
         return result['total'] or 0.0
-    
+
     def average_cost(self):
         """Get average monthly cost."""
         result = self.aggregate(avg=models.Avg('monthly_cost_usd'))
         return result['avg'] or 0.0
-    
+
     def count_by_tier(self):
         """Get count of subscriptions grouped by tier."""
         return self.values('tier').annotate(count=models.Count('id')).order_by('tier')
-    
+
     def count_by_status(self):
         """Get count of subscriptions grouped by status."""
         return self.values('status').annotate(count=models.Count('id')).order_by('status')
-    
+
     def usage_stats(self):
         """Get usage statistics."""
         return self.aggregate(
@@ -207,41 +209,41 @@ class SubscriptionManager(models.Manager):
     
     Provides high-level methods for subscription management and access control.
     """
-    
+
     def get_queryset(self):
         """Return optimized queryset by default."""
         return SubscriptionQuerySet(self.model, using=self._db)
-    
+
     def optimized(self):
         """Get optimized queryset."""
         return self.get_queryset().optimized()
-    
+
     # Status-based methods
     def active(self):
         """Get active subscriptions."""
         return self.get_queryset().active()
-    
+
     def expired(self):
         """Get expired subscriptions."""
         return self.get_queryset().expired()
-    
+
     def expiring_soon(self, days=7):
         """Get subscriptions expiring soon."""
         return self.get_queryset().expiring_soon(days)
-    
+
     # Tier-based methods
     def by_tier(self, tier):
         """Get subscriptions by tier."""
         return self.get_queryset().by_tier(tier)
-    
+
     def free_tier(self):
         """Get free tier subscriptions."""
         return self.get_queryset().free_tier()
-    
+
     def paid_tiers(self):
         """Get paid tier subscriptions."""
         return self.get_queryset().paid_tiers()
-    
+
     # User methods
     def get_active_for_user(self, user):
         """
@@ -257,7 +259,7 @@ class SubscriptionManager(models.Manager):
             return self.active().get(user=user)
         except self.model.DoesNotExist:
             return None
-    
+
     def has_active_subscription(self, user):
         """
         Check if user has an active subscription.
@@ -269,7 +271,7 @@ class SubscriptionManager(models.Manager):
             bool: True if user has active subscription
         """
         return self.active().filter(user=user).exists()
-    
+
     def get_or_create_free_subscription(self, user):
         """
         Get existing subscription or create free tier subscription for user.
@@ -284,17 +286,17 @@ class SubscriptionManager(models.Manager):
         existing = self.get_active_for_user(user)
         if existing:
             return existing, False
-        
+
         # Create free subscription
         subscription = self.model.create_free_subscription(user)
-        
-        logger.info(f"Created free subscription for user", extra={
+
+        logger.info("Created free subscription for user", extra={
             'user_id': user.id,
             'subscription_id': str(subscription.id)
         })
-        
+
         return subscription, True
-    
+
     # Access control methods
     def check_endpoint_access(self, user, endpoint_group_code):
         """
@@ -310,9 +312,9 @@ class SubscriptionManager(models.Manager):
         subscription = self.get_active_for_user(user)
         if not subscription:
             return False
-        
+
         return subscription.has_access_to_endpoint_group(endpoint_group_code)
-    
+
     def get_user_rate_limits(self, user):
         """
         Get rate limits for user based on their subscription.
@@ -330,7 +332,7 @@ class SubscriptionManager(models.Manager):
                 'requests_per_day': 0,
                 'has_access': False
             }
-        
+
         return {
             'requests_per_hour': subscription.requests_per_hour,
             'requests_per_day': subscription.requests_per_day,
@@ -338,7 +340,7 @@ class SubscriptionManager(models.Manager):
             'tier': subscription.tier,
             'expires_at': subscription.expires_at
         }
-    
+
     # Maintenance methods
     def cleanup_expired(self, dry_run=True):
         """
@@ -355,13 +357,13 @@ class SubscriptionManager(models.Manager):
             status__in=['active', 'suspended']
         )
         count = expired_subscriptions.count()
-        
+
         if not dry_run and count > 0:
             expired_subscriptions.update(status='expired')
             logger.info(f"Marked {count} subscriptions as expired")
-        
+
         return count
-    
+
     def process_auto_renewals(self, dry_run=True):
         """
         Process auto-renewal for subscriptions expiring soon.
@@ -379,14 +381,14 @@ class SubscriptionManager(models.Manager):
             auto_renew=True,
             status='active'
         )
-        
+
         count = expiring_subscriptions.count()
-        
+
         if not dry_run and count > 0:
             for subscription in expiring_subscriptions:
                 try:
                     subscription.renew(duration_days=30)
-                    logger.info(f"Auto-renewed subscription", extra={
+                    logger.info("Auto-renewed subscription", extra={
                         'subscription_id': str(subscription.id),
                         'user_id': subscription.user.id
                     })
@@ -395,9 +397,9 @@ class SubscriptionManager(models.Manager):
                         'subscription_id': str(subscription.id),
                         'user_id': subscription.user.id
                     })
-        
+
         return count
-    
+
     # Statistics methods
     def get_subscription_stats(self, days=30):
         """
@@ -411,7 +413,7 @@ class SubscriptionManager(models.Manager):
         """
         queryset = self.get_queryset()
         recent_queryset = queryset.created_recently(days)
-        
+
         stats = {
             'total_subscriptions': queryset.count(),
             'active_subscriptions': queryset.active().count(),
@@ -425,15 +427,15 @@ class SubscriptionManager(models.Manager):
             'auto_renewing': queryset.auto_renewing().count(),
             'expiring_soon': queryset.expiring_soon(7).count(),
         }
-        
+
         logger.info(f"Generated subscription stats for {days} days", extra={
             'days': days,
             'total_subscriptions': stats['total_subscriptions'],
             'active_subscriptions': stats['active_subscriptions']
         })
-        
+
         return stats
-    
+
     def get_tier_analytics(self):
         """
         Get detailed analytics by subscription tier.
@@ -442,10 +444,10 @@ class SubscriptionManager(models.Manager):
             dict: Tier-based analytics
         """
         analytics = {}
-        
+
         for tier_code, tier_name in self.model.SubscriptionTier.choices:
             tier_subscriptions = self.by_tier(tier_code)
-            
+
             analytics[tier_code] = {
                 'name': tier_name,
                 'total_count': tier_subscriptions.count(),
@@ -456,9 +458,9 @@ class SubscriptionManager(models.Manager):
                 )['avg'] or 0,
                 'conversion_rate': 0.0  # Would need additional logic for conversion tracking
             }
-        
+
         return analytics
-    
+
     # Business logic methods
     def activate_subscription(self, subscription_id):
         """
@@ -475,23 +477,23 @@ class SubscriptionManager(models.Manager):
                 subscription = self.get(id=subscription_id)
             else:
                 subscription = subscription_id
-            
+
             subscription.status = subscription.model.SubscriptionStatus.ACTIVE
             subscription.save(update_fields=['status', 'updated_at'])
-            
-            logger.info(f"Subscription activated", extra={
+
+            logger.info("Subscription activated", extra={
                 'subscription_id': str(subscription.id),
                 'user_id': subscription.user.id
             })
-            
+
             return True
-            
+
         except Exception as e:
             logger.error(f"Failed to activate subscription: {e}", extra={
                 'subscription_id': str(subscription_id) if hasattr(subscription_id, 'id') else subscription_id
             })
             return False
-    
+
     def suspend_subscription(self, subscription_id, reason=None):
         """
         Suspend subscription (business logic in manager).
@@ -508,24 +510,24 @@ class SubscriptionManager(models.Manager):
                 subscription = self.get(id=subscription_id)
             else:
                 subscription = subscription_id
-            
+
             subscription.status = subscription.model.SubscriptionStatus.SUSPENDED
             subscription.save(update_fields=['status', 'updated_at'])
-            
-            logger.warning(f"Subscription suspended", extra={
+
+            logger.warning("Subscription suspended", extra={
                 'subscription_id': str(subscription.id),
                 'user_id': subscription.user.id,
                 'reason': reason
             })
-            
+
             return True
-            
+
         except Exception as e:
             logger.error(f"Failed to suspend subscription: {e}", extra={
                 'subscription_id': str(subscription_id) if hasattr(subscription_id, 'id') else subscription_id
             })
             return False
-    
+
     def cancel_subscription(self, subscription_id, reason=None):
         """
         Cancel subscription (business logic in manager).
@@ -542,24 +544,24 @@ class SubscriptionManager(models.Manager):
                 subscription = self.get(id=subscription_id)
             else:
                 subscription = subscription_id
-            
+
             subscription.status = self.model.SubscriptionStatus.CANCELLED
             subscription.save(update_fields=['status', 'updated_at'])
-            
-            logger.info(f"Subscription cancelled", extra={
+
+            logger.info("Subscription cancelled", extra={
                 'subscription_id': str(subscription.id),
                 'user_id': subscription.user.id,
                 'reason': reason
             })
-            
+
             return True
-            
+
         except Exception as e:
             logger.error(f"Failed to cancel subscription: {e}", extra={
                 'subscription_id': str(subscription_id) if hasattr(subscription_id, 'id') else subscription_id
             })
             return False
-    
+
     def renew_subscription(self, subscription_id, duration_days=30):
         """
         Renew subscription (business logic in manager).
@@ -576,9 +578,9 @@ class SubscriptionManager(models.Manager):
                 subscription = self.get(id=subscription_id)
             else:
                 subscription = subscription_id
-            
+
             from datetime import timedelta
-            
+
             if subscription.expires_at <= timezone.now():
                 # If expired, start from now
                 subscription.starts_at = timezone.now()
@@ -586,25 +588,25 @@ class SubscriptionManager(models.Manager):
             else:
                 # If not expired, extend from current expiration
                 subscription.expires_at += timedelta(days=duration_days)
-            
+
             subscription.status = self.model.SubscriptionStatus.ACTIVE
             subscription.save(update_fields=['starts_at', 'expires_at', 'status', 'updated_at'])
-            
-            logger.info(f"Subscription renewed", extra={
+
+            logger.info("Subscription renewed", extra={
                 'subscription_id': str(subscription.id),
                 'user_id': subscription.user.id,
                 'duration_days': duration_days,
                 'new_expires_at': subscription.expires_at.isoformat()
             })
-            
+
             return True
-            
+
         except Exception as e:
             logger.error(f"Failed to renew subscription: {e}", extra={
                 'subscription_id': str(subscription_id) if hasattr(subscription_id, 'id') else subscription_id
             })
             return False
-    
+
     def increment_subscription_usage(self, subscription_id):
         """
         Increment usage counter for subscription (business logic in manager).
@@ -620,19 +622,19 @@ class SubscriptionManager(models.Manager):
                 subscription = self.get(id=subscription_id)
             else:
                 subscription = subscription_id
-            
+
             subscription.total_requests += 1
             subscription.last_request_at = timezone.now()
             subscription.save(update_fields=['total_requests', 'last_request_at', 'updated_at'])
-            
-            logger.debug(f"Incremented subscription usage", extra={
+
+            logger.debug("Incremented subscription usage", extra={
                 'subscription_id': str(subscription.id),
                 'user_id': subscription.user.id,
                 'total_requests': subscription.total_requests
             })
-            
+
             return True
-            
+
         except Exception as e:
             logger.error(f"Failed to increment subscription usage: {e}", extra={
                 'subscription_id': str(subscription_id) if hasattr(subscription_id, 'id') else subscription_id
