@@ -5,13 +5,16 @@ Abstract base class for all payment providers with unified interface.
 """
 
 from abc import ABC, abstractmethod
-from typing import Dict, Any, Optional
 from decimal import Decimal
+from typing import Any, Dict, Optional
+
 import requests
 from django.utils import timezone
+
 from django_cfg.modules.django_logging import get_logger
+
 from ..types import ProviderResponse, ServiceOperationResult
-from .models import ProviderConfig, PaymentRequest, WithdrawalRequest
+from .models import PaymentRequest, ProviderConfig, WithdrawalRequest
 
 
 class BaseProvider(ABC):
@@ -20,7 +23,7 @@ class BaseProvider(ABC):
     
     Defines the unified interface that all providers must implement.
     """
-    
+
     def __init__(self, config: ProviderConfig):
         """
         Initialize provider with configuration.
@@ -31,17 +34,17 @@ class BaseProvider(ABC):
         self.config = config
         self.logger = get_logger(f"providers.{config.provider_name}")
         self._session = None
-    
+
     @property
     def name(self) -> str:
         """Get provider name."""
         return self.config.provider_name
-    
+
     @property
     def is_sandbox(self) -> bool:
         """Check if provider is in sandbox mode."""
         return self.config.sandbox_mode
-    
+
     # Provider configuration methods (to be overridden by specific providers)
     def get_fee_percentage(self, currency_code: str = None, currency_type: str = None) -> Decimal:
         """
@@ -55,7 +58,7 @@ class BaseProvider(ABC):
             Fee percentage as decimal (0.005 = 0.5%)
         """
         return Decimal('0.005')  # Default 0.5%
-    
+
     def get_fixed_fee_usd(self, currency_code: str = None, currency_type: str = None) -> Decimal:
         """
         Get fixed fee in USD for currency.
@@ -68,7 +71,7 @@ class BaseProvider(ABC):
             Fixed fee in USD
         """
         return Decimal('0.0')  # Default no fixed fee
-    
+
     def get_min_amount_usd(self, currency_code: str = None, currency_type: str = None, is_stable: bool = False) -> Decimal:
         """
         Get minimum amount in USD for currency.
@@ -87,7 +90,7 @@ class BaseProvider(ABC):
             return Decimal('0.01')
         else:
             return Decimal('0.000001')
-    
+
     def get_max_amount_usd(self, currency_code: str = None, currency_type: str = None) -> Decimal:
         """
         Get maximum amount in USD for currency.
@@ -100,7 +103,7 @@ class BaseProvider(ABC):
             Maximum amount in USD
         """
         return Decimal('1000000.0')  # Default 1M USD
-    
+
     def get_confirmation_blocks(self, network_code: str) -> int:
         """
         Get confirmation blocks for network.
@@ -112,7 +115,7 @@ class BaseProvider(ABC):
             Number of confirmation blocks
         """
         return 1  # Default 1 confirmation
-    
+
     def get_network_name(self, network_code: str) -> str:
         """
         Get human-readable network name.
@@ -124,7 +127,7 @@ class BaseProvider(ABC):
             Human-readable network name
         """
         return network_code.upper() if network_code else 'Unknown'
-    
+
     @abstractmethod
     def create_payment(self, request: PaymentRequest) -> ProviderResponse:
         """
@@ -137,7 +140,7 @@ class BaseProvider(ABC):
             ProviderResponse: Provider response with payment details
         """
         pass
-    
+
     @abstractmethod
     def get_payment_status(self, provider_payment_id: str) -> ProviderResponse:
         """
@@ -150,7 +153,7 @@ class BaseProvider(ABC):
             ProviderResponse: Current payment status
         """
         pass
-    
+
     def refresh_payment_status(self, provider_payment_id: str, force_update: bool = True) -> ProviderResponse:
         """
         Refresh payment status with enhanced error handling and caching control.
@@ -172,11 +175,11 @@ class BaseProvider(ABC):
             'payment_id': provider_payment_id,
             'force_update': force_update
         })
-        
+
         try:
             # Call the provider-specific implementation
             result = self.get_payment_status(provider_payment_id)
-            
+
             # Add refresh metadata
             if result.success and hasattr(result, 'raw_response') and result.raw_response:
                 result.raw_response['_refresh_metadata'] = {
@@ -184,28 +187,28 @@ class BaseProvider(ABC):
                     'provider': self.name,
                     'force_update': force_update
                 }
-            
-            self.logger.info(f"Payment status refreshed successfully", extra={
+
+            self.logger.info("Payment status refreshed successfully", extra={
                 'provider': self.name,
                 'payment_id': provider_payment_id,
                 'status': getattr(result, 'status', 'unknown')
             })
-            
+
             return result
-            
+
         except Exception as e:
-            self.logger.error(f"Failed to refresh payment status", extra={
+            self.logger.error("Failed to refresh payment status", extra={
                 'provider': self.name,
                 'payment_id': provider_payment_id,
                 'error': str(e)
             })
-            
+
             return ProviderResponse(
                 success=False,
                 error_message=f"Failed to refresh payment status: {str(e)}",
                 raw_response={'error': str(e), 'provider': self.name}
             )
-    
+
     @abstractmethod
     def get_supported_currencies(self) -> ServiceOperationResult:
         """
@@ -215,7 +218,7 @@ class BaseProvider(ABC):
             ServiceOperationResult: List of supported currencies
         """
         pass
-    
+
     @abstractmethod
     def sync_currencies_to_db(self):
         """
@@ -225,7 +228,7 @@ class BaseProvider(ABC):
             CurrencySyncResult: Synchronization result
         """
         pass
-    
+
     @abstractmethod
     def validate_webhook(self, payload: Dict[str, Any], signature: str = None) -> ServiceOperationResult:
         """
@@ -239,9 +242,9 @@ class BaseProvider(ABC):
             ServiceOperationResult: Validation result
         """
         pass
-    
+
     # Withdrawal/Payout Methods
-    
+
     def supports_withdrawals(self) -> bool:
         """
         Check if provider supports withdrawals/payouts.
@@ -250,7 +253,7 @@ class BaseProvider(ABC):
             bool: True if provider supports withdrawals
         """
         return False  # Default: most payment processors don't support withdrawals
-    
+
     def create_withdrawal(self, request: WithdrawalRequest) -> ProviderResponse:
         """
         Create withdrawal/payout request with provider.
@@ -270,9 +273,9 @@ class BaseProvider(ABC):
                 error_message=f"Provider {self.name} does not support withdrawals",
                 raw_response={'error': 'withdrawals_not_supported'}
             )
-        
+
         raise NotImplementedError("Subclasses must implement create_withdrawal if they support withdrawals")
-    
+
     def get_withdrawal_status(self, provider_withdrawal_id: str) -> ProviderResponse:
         """
         Get withdrawal status from provider.
@@ -292,9 +295,9 @@ class BaseProvider(ABC):
                 error_message=f"Provider {self.name} does not support withdrawals",
                 raw_response={'error': 'withdrawals_not_supported'}
             )
-        
+
         raise NotImplementedError("Subclasses must implement get_withdrawal_status if they support withdrawals")
-    
+
     def cancel_withdrawal(self, provider_withdrawal_id: str) -> ProviderResponse:
         """
         Cancel pending withdrawal.
@@ -314,13 +317,13 @@ class BaseProvider(ABC):
                 error_message=f"Provider {self.name} does not support withdrawals",
                 raw_response={'error': 'withdrawals_not_supported'}
             )
-        
+
         return ProviderResponse(
             success=False,
             error_message=f"Provider {self.name} does not support withdrawal cancellation",
             raw_response={'error': 'withdrawal_cancellation_not_supported'}
         )
-    
+
     def get_withdrawal_fees(self, currency_code: str) -> ServiceOperationResult:
         """
         Get withdrawal fees for specific currency.
@@ -336,12 +339,12 @@ class BaseProvider(ABC):
                 success=False,
                 message=f"Provider {self.name} does not support withdrawals"
             )
-        
+
         return ServiceOperationResult(
             success=False,
             message="Withdrawal fee information not available"
         )
-    
+
     def get_minimum_withdrawal_amount(self, currency_code: str) -> ServiceOperationResult:
         """
         Get minimum withdrawal amount for specific currency.
@@ -357,12 +360,12 @@ class BaseProvider(ABC):
                 success=False,
                 message=f"Provider {self.name} does not support withdrawals"
             )
-        
+
         return ServiceOperationResult(
             success=False,
             message="Minimum withdrawal amount information not available"
         )
-    
+
     def get_exchange_rate(self, from_currency: str, to_currency: str) -> ServiceOperationResult:
         """
         Get exchange rate from provider (optional).
@@ -379,7 +382,7 @@ class BaseProvider(ABC):
             message=f"Exchange rates not supported by {self.name}",
             error_code="not_supported"
         )
-    
+
     def health_check(self) -> ServiceOperationResult:
         """
         Perform provider health check.
@@ -390,7 +393,7 @@ class BaseProvider(ABC):
         try:
             # Basic connectivity test - can be overridden by providers
             result = self.get_supported_currencies()
-            
+
             if result.success:
                 return ServiceOperationResult(
                     success=True,
@@ -409,7 +412,7 @@ class BaseProvider(ABC):
                     error_code="health_check_failed",
                     data={'provider': self.name, 'error': result.message}
                 )
-                
+
         except Exception as e:
             self.logger.error(f"Health check failed for {self.name}: {e}")
             return ServiceOperationResult(
@@ -418,7 +421,7 @@ class BaseProvider(ABC):
                 error_code="health_check_error",
                 data={'provider': self.name}
             )
-    
+
     def _make_request(
         self,
         method: str,
@@ -441,14 +444,13 @@ class BaseProvider(ABC):
         Raises:
             Exception: If request fails
         """
-        import requests
         from requests.adapters import HTTPAdapter
         from urllib3.util.retry import Retry
-        
+
         # Create session if not exists
         if self._session is None:
             self._session = requests.Session()
-            
+
             # Configure retries
             retry_strategy = Retry(
                 total=self.config.retry_attempts,
@@ -458,10 +460,10 @@ class BaseProvider(ABC):
             adapter = HTTPAdapter(max_retries=retry_strategy)
             self._session.mount("http://", adapter)
             self._session.mount("https://", adapter)
-        
+
         # Build URL
         url = f"{self.config.api_url.rstrip('/')}/{endpoint.lstrip('/')}"
-        
+
         # Prepare headers
         request_headers = {
             'Content-Type': 'application/json',
@@ -469,14 +471,14 @@ class BaseProvider(ABC):
         }
         if headers:
             request_headers.update(headers)
-        
+
         # Log request
         self.logger.debug(f"Making {method} request to {url}", extra={
             'method': method,
             'url': url,
             'has_data': bool(data)
         })
-        
+
         # Make request
         response = self._session.request(
             method=method,
@@ -485,17 +487,17 @@ class BaseProvider(ABC):
             headers=request_headers,
             timeout=self.config.timeout
         )
-        
+
         # Log response
         self.logger.debug(f"Received response: {response.status_code}", extra={
             'status_code': response.status_code,
             'response_size': len(response.content)
         })
-        
+
         # Handle response
         try:
             response.raise_for_status()
-        except requests.exceptions.HTTPError as e:
+        except requests.exceptions.HTTPError:
             # Log the error with response content for debugging
             error_content = response.text if response.text else "No response content"
             self.logger.error(f"HTTP {response.status_code} error from {self.name}", extra={
@@ -503,7 +505,7 @@ class BaseProvider(ABC):
                 'error_content': error_content[:500],  # Limit content length
                 'url': response.url
             })
-            
+
             # Handle specific HTTP errors
             if response.status_code == 403:
                 if "blocked" in error_content.lower() or "nowpayments.io" in error_content:
@@ -520,13 +522,13 @@ class BaseProvider(ABC):
                 raise Exception(f"{self.name} server error ({response.status_code}). Please try again later.")
             else:
                 raise Exception(f"HTTP {response.status_code} error from {self.name}: {error_content[:200]}")
-        
+
         try:
             return response.json()
         except ValueError:
             # Non-JSON response
             return {'raw_response': response.text, 'status_code': response.status_code}
-    
+
     def _create_provider_response(
         self,
         success: bool,
@@ -550,11 +552,11 @@ class BaseProvider(ABC):
             raw_response=raw_response,
             **kwargs
         )
-    
+
     def __str__(self) -> str:
         """String representation."""
         return f"{self.name}Provider(sandbox={self.is_sandbox})"
-    
+
     def __repr__(self) -> str:
         """Detailed representation."""
         return f"{self.__class__.__name__}(name='{self.name}', sandbox={self.is_sandbox}, api_url='{self.config.api_url}')"
