@@ -4,18 +4,18 @@ NowPayments provider package for Universal Payment System v2.0.
 Comprehensive NowPayments integration with currency synchronization.
 """
 
-from .provider import NowPaymentsProvider
+from .config import NowPaymentsConfig
 from .models import (
-    NowPaymentsProviderConfig,
     NowPaymentsCurrency,
     NowPaymentsFullCurrenciesResponse,
     NowPaymentsPaymentRequest,
     NowPaymentsPaymentResponse,
+    NowPaymentsProviderConfig,
+    NowPaymentsStatusResponse,
     NowPaymentsWebhook,
-    NowPaymentsStatusResponse
 )
+from .provider import NowPaymentsProvider
 from .sync import NowPaymentsCurrencySync
-from .config import NowPaymentsConfig
 
 __all__ = [
     'NowPaymentsProvider',
