@@ -4,9 +4,9 @@ Support admin interfaces using Django-CFG admin system.
 Refactored admin interfaces with Material Icons and optimized queries.
 """
 
-from .support_admin import TicketAdmin, MessageAdmin
-from .filters import TicketUserEmailFilter, TicketUserNameFilter, MessageSenderEmailFilter
-from .resources import TicketResource, MessageResource
+from .filters import MessageSenderEmailFilter, TicketUserEmailFilter, TicketUserNameFilter
+from .resources import MessageResource, TicketResource
+from .support_admin import MessageAdmin, TicketAdmin
 
 __all__ = [
     'TicketAdmin',
