@@ -7,7 +7,7 @@ Extracted from original config.py for better maintainability.
 Size: ~100 lines (focused on security)
 """
 
-from typing import List, TYPE_CHECKING
+from typing import TYPE_CHECKING, List
 
 if TYPE_CHECKING:
     from ..base.config_model import DjangoConfig
