@@ -5,20 +5,20 @@ Manages dashboard configuration, widgets, and navigation
 based on the working configuration from the old version.
 """
 
-from typing import List, Dict, Any, Optional
-from django.templatetags.static import static
-from django.urls import reverse_lazy
-from ..base import BaseCfgModule
+from typing import Any, Dict, List
+
 from django_cfg.modules.django_admin.icons import Icons
-from .models.navigation import NavigationSection, NavigationItem
+
+from ..base import BaseCfgModule
 from .models.dashboard import StatCard, StatsCardsWidget
+from .models.navigation import NavigationItem, NavigationSection
 
 
 class DashboardManager(BaseCfgModule):
     """
     Dashboard configuration manager for Unfold.    
     """
-    
+
     def __init__(self, config=None):
         """Initialize dashboard manager."""
         super().__init__()
@@ -48,8 +48,8 @@ class DashboardManager(BaseCfgModule):
 
         # Convert SiteDropdownItem objects to dictionaries for Unfold
         return [item.to_dict() for item in dropdown_items]
-    
-    
+
+
     def get_navigation_config(self) -> List[Dict[str, Any]]:
         """Get complete default navigation configuration for Unfold sidebar."""
         navigation_sections = [
@@ -72,14 +72,14 @@ class DashboardManager(BaseCfgModule):
         # RPC Dashboard (if enabled)
         if self.is_rpc_enabled():
             operations_items.append(
-                NavigationItem(title="RPC Dashboard", icon=Icons.MONITOR_HEART, link="/cfg/admin/rpc/")
+                NavigationItem(title="IPC/RPC Dashboard", icon=Icons.MONITOR_HEART, link="/cfg/ipc/admin/")
             )
 
         # Background Tasks (if enabled)
         if self.should_enable_tasks():
             operations_items.extend([
                 NavigationItem(title="Background Tasks", icon=Icons.TASK, link="/admin/django_dramatiq/task/"),
-                NavigationItem(title="Task Dashboard", icon=Icons.SETTINGS_APPLICATIONS, link="/cfg/admin/django_cfg_tasks/admin/dashboard/"),
+                NavigationItem(title="Task Dashboard", icon=Icons.SETTINGS_APPLICATIONS, link="/cfg/tasks/admin/dashboard/"),
             ])
 
         # Maintenance Mode (if enabled)
@@ -96,7 +96,7 @@ class DashboardManager(BaseCfgModule):
                 collapsible=True,
                 items=operations_items
             ))
-        
+
         # Add Accounts section if enabled
         if self.is_accounts_enabled():
             navigation_sections.append(NavigationSection(
@@ -110,7 +110,7 @@ class DashboardManager(BaseCfgModule):
                     NavigationItem(title="User Registration Sources", icon=Icons.PERSON, link="/admin/django_cfg_accounts/userregistrationsource/"),
                 ]
             ))
-        
+
         # Add Support section if enabled
         if self.is_support_enabled():
             navigation_sections.append(NavigationSection(
@@ -122,7 +122,7 @@ class DashboardManager(BaseCfgModule):
                     NavigationItem(title="Messages", icon=Icons.CHAT, link="/admin/django_cfg_support/message/"),
                 ]
             ))
-        
+
         # Add Newsletter section if enabled
         if self.is_newsletter_enabled():
             navigation_sections.append(NavigationSection(
@@ -136,7 +136,7 @@ class DashboardManager(BaseCfgModule):
                     NavigationItem(title="Email Logs", icon=Icons.MAIL_OUTLINE, link="/admin/django_cfg_newsletter/emaillog/"),
                 ]
             ))
-        
+
         # Add Leads section if enabled
         if self.is_leads_enabled():
             navigation_sections.append(NavigationSection(
@@ -147,7 +147,7 @@ class DashboardManager(BaseCfgModule):
                     NavigationItem(title="Leads", icon=Icons.CONTACT_PAGE, link="/admin/django_cfg_leads/lead/"),
                 ]
             ))
-        
+
         # Add Agents section if enabled
         if self.is_agents_enabled():
             navigation_sections.append(NavigationSection(
@@ -163,7 +163,7 @@ class DashboardManager(BaseCfgModule):
                     NavigationItem(title="Toolset Configurations", icon=Icons.SETTINGS, link="/admin/django_cfg_agents/toolsetconfiguration/"),
                 ]
             ))
-        
+
         # Add Knowledge Base section if enabled
         if self.is_knowbase_enabled():
             navigation_sections.append(NavigationSection(
@@ -194,7 +194,7 @@ class DashboardManager(BaseCfgModule):
 
                 # Main dashboard (always show if payments app enabled)
                 payments_items.append(
-                    NavigationItem(title="Payment Dashboard", icon=Icons.DASHBOARD, link="/cfg/admin/django_cfg_payments/admin/")
+                    NavigationItem(title="Payment Dashboard", icon=Icons.DASHBOARD, link="/cfg/payments/admin/")
                 )
 
                 # Always show basic admin models (even if payments functionality is disabled)
@@ -208,13 +208,13 @@ class DashboardManager(BaseCfgModule):
                 # Add advanced features only if payments functionality is enabled
                 if config.enabled:
                     # payments_items.append(
-                    #     NavigationItem(title="Webhook Dashboard", icon=Icons.WEBHOOK, link="/cfg/admin/django_cfg_payments/admin/webhooks/")
+                    #     NavigationItem(title="Webhook Dashboard", icon=Icons.WEBHOOK, link="/cfg/payments/admin/webhooks/")
                     # )
                     # payments_items.append(
-                    #     NavigationItem(title="Create Payment", icon=Icons.ADD, link="/cfg/admin/django_cfg_payments/admin/payments/create/")
+                    #     NavigationItem(title="Create Payment", icon=Icons.ADD, link="/cfg/payments/admin/payments/create/")
                     # )
                     # payments_items.append(
-                    #     NavigationItem(title="Currency Converter", icon=Icons.CURRENCY_EXCHANGE, link="/cfg/admin/django_cfg_payments/admin/tools/converter/")
+                    #     NavigationItem(title="Currency Converter", icon=Icons.CURRENCY_EXCHANGE, link="/cfg/payments/admin/tools/converter/")
                     # )
 
                     # Show subscription features only if enabled
@@ -246,7 +246,7 @@ class DashboardManager(BaseCfgModule):
             except Exception:
                 # Fallback
                 payments_items = [
-                    NavigationItem(title="Payment Dashboard", icon=Icons.DASHBOARD, link="/cfg/admin/django_cfg_payments/admin/"),
+                    NavigationItem(title="Payment Dashboard", icon=Icons.DASHBOARD, link="/cfg/payments/admin/"),
                     NavigationItem(title="Universal Payments", icon=Icons.ACCOUNT_BALANCE, link="/admin/payments/universalpayment/"),
                 ]
 
@@ -259,9 +259,9 @@ class DashboardManager(BaseCfgModule):
 
         # Convert all NavigationSection objects to dictionaries
         return [section.to_dict() for section in navigation_sections]
-        
-    
-    
+
+
+
     def get_unfold_config(self) -> Dict[str, Any]:
         """Get complete Unfold configuration based on working old version."""
         return {
@@ -271,23 +271,23 @@ class DashboardManager(BaseCfgModule):
             "SITE_SUBHEADER": "",
             "SITE_URL": "/",
             "SITE_SYMBOL": "dashboard",
-            
+
             # UI visibility controls
             "SHOW_HISTORY": True,
             "SHOW_VIEW_ON_SITE": True,
             "SHOW_BACK_BUTTON": False,
-            
+
             # Dashboard callback
             "DASHBOARD_CALLBACK": "api.dashboard.callbacks.main_dashboard_callback",
-            
+
             # Theme configuration
             "THEME": None,  # Auto-detect or force "dark"/"light"
-            
+
             # Login page customization
             "LOGIN": {
                 "redirect_after": lambda request: "/admin/",
             },
-            
+
             # Design system
             "BORDER_RADIUS": "8px",
             "COLORS": {
@@ -326,7 +326,7 @@ class DashboardManager(BaseCfgModule):
                     "important-dark": "var(--color-base-100)",
                 },
             },
-            
+
             # Sidebar navigation - KEY STRUCTURE!
             "SIDEBAR": {
                 "show_search": True,
@@ -334,20 +334,20 @@ class DashboardManager(BaseCfgModule):
                 "show_all_applications": True,
                 "navigation": self.get_navigation_config(),
             },
-            
+
             # Site dropdown menu - handled by config.py to allow extending
             # "SITE_DROPDOWN": self._get_default_dropdown_items(),
-            
+
             # Command interface
             "COMMAND": {
                 "search_models": True,
                 "show_history": True,
             },
-            
+
             # Multi-language support - DISABLED
             "SHOW_LANGUAGES": False,
         }
-    
+
     def get_widgets_config(self) -> List[Dict[str, Any]]:
         """Get dashboard widgets configuration using Pydantic models."""
         # Create system overview widget with StatCard models
@@ -374,7 +374,7 @@ class DashboardManager(BaseCfgModule):
                 ),
             ]
         )
-        
+
         # Convert to dictionaries for Unfold
         return [system_overview_widget.to_dict()]
 
